@@ -12,6 +12,7 @@ from dataclasses import dataclass, field
 from typing import (
     Any,
     Callable,
+    Coroutine,
     Dict,
     Generic,
     Iterator,
@@ -455,7 +456,11 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
     def _handle_body(self, body: bytes, charset: str) -> None:
         try:
-            self._handle_messages(self._generate_json_rpc_messages_from_dict(json.loads(body.decode(charset))))
+            b = body.decode(charset)
+
+            self._data_logger.trace(lambda: f"JSON Received: {b}")
+
+            self._handle_messages(self._generate_json_rpc_messages_from_dict(json.loads(b)))
         except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
             raise
         except BaseException as e:
@@ -518,7 +523,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         if self.write_transport is not None:
             msg = header + body
 
-            self._data_logger.trace(lambda: f"JSON Message: {msg.decode()}")
+            self._data_logger.trace(lambda: f"JSON send: {msg.decode()}")
 
             if self._loop:
                 self._loop.call_soon_threadsafe(self.write_transport.write, msg)
@@ -722,7 +727,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             params = self._convert_params(e.method, e.param_type, message.params)
             result = e.method(*params[0], **params[1])
             if inspect.isawaitable(result):
-                create_sub_task(result)
+                create_sub_task(cast(Coroutine[Any, Any, Any], result))
 
         except asyncio.CancelledError:
             pass
