@@ -13,6 +13,30 @@ URI = str
 ProgressToken = Union[str, int]
 
 
+class ErrorCodes:
+    PARSE_ERROR = -32700
+    INVALID_REQUEST = -32600
+    METHOD_NOT_FOUND = -32601
+    INVALID_PARAMS = -32602
+    INTERNAL_ERROR = -32603
+    SERVER_ERROR_START = -32000
+    SERVER_ERROR_END = -32099
+
+    JSON_RPC_RESERVED_ERROR_RANGE_START = -32099
+
+    SERVER_NOT_INITIALIZED = -32002
+    UNKNOWN_ERROR = -32001
+
+    JSON_RPC_RESERVED_ERROR_RANGE_END = -32000
+
+    LSP_RESERVED_ERROR_RANGE_START = -32899
+    REQUEST_FAILED = -32803
+    SERVER_CANCELLED = -32802
+    CONTENT_MODIFIED = -32801
+    REQUEST_CANCELLED = -32800
+    LSP_RESERVED_ERROR_RANGE_END = -32800
+
+
 @dataclass(repr=False)
 class Model:
     @classmethod
@@ -30,12 +54,9 @@ class Model:
             for f in dataclasses.fields(self)
             if f.repr
             and (
-                (f.default == dataclasses.MISSING and f.default_factory == dataclasses.MISSING)  # type: ignore
+                (f.default == dataclasses.MISSING and f.default_factory == dataclasses.MISSING)
                 or (f.default != dataclasses.MISSING and f.default != getattr(self, f.name))
-                or (
-                    f.default_factory != dataclasses.MISSING  # type: ignore
-                    and getattr(self, f.name) != f.default_factory()
-                )
+                or (f.default_factory != dataclasses.MISSING and getattr(self, f.name) != f.default_factory())
             )
         )
         return f"{self.__class__.__qualname__}({args})"
@@ -488,11 +509,32 @@ class PublishDiagnosticsClientCapabilities(Model):
     data_support: Optional[bool] = None
 
 
+class FoldingRangeKind(Enum):
+    COMMENT = "comment"
+    IMPORTS = "imports"
+    REGION = "region"
+
+    def __repr__(self) -> str:  # pragma: no cover
+        return super().__str__()
+
+
+@dataclass(repr=False)
+class FoldingRangeClientCapabilitiesFoldingRangeKind(Model):
+    value_set: Optional[List[FoldingRangeKind]]
+
+
+@dataclass(repr=False)
+class FoldingRangeClientCapabilitiesFoldingRange(Model):
+    collapsed_text: Optional[bool] = None
+
+
 @dataclass(repr=False)
 class FoldingRangeClientCapabilities(Model):
     dynamic_registration: Optional[bool] = None
     range_limit: Optional[int] = None
     line_folding_only: Optional[bool] = None
+    folding_range_kind: Optional[FoldingRangeClientCapabilitiesFoldingRangeKind] = None
+    folding_range: Optional[FoldingRangeClientCapabilitiesFoldingRange] = None
 
 
 @dataclass(repr=False)
@@ -536,6 +578,8 @@ class SemanticTokensClientCapabilities(Model):
     formats: List[TokenFormat]
     overlapping_token_support: Optional[bool] = None
     multiline_token_support: Optional[bool] = None
+    server_cancel_support: Optional[bool] = None
+    augments_syntax_tokens: Optional[bool] = None
     dynamic_registration: Optional[bool] = None
 
 
@@ -544,6 +588,28 @@ class MonikerClientCapabilities(Model):
     dynamic_registration: Optional[bool] = None
 
 
+@dataclass(repr=False)
+class InlayHintClientCapabilitiesResolveSupport(Model):
+    properties: List[str]
+
+
+@dataclass(repr=False)
+class InlayHintClientCapabilities(Model):
+    dynamic_registration: Optional[bool] = None
+    resolve_support: Optional[InlayHintClientCapabilitiesResolveSupport] = None
+
+
+@dataclass(repr=False)
+class InlineValueClientCapabilities(Model):
+    dynamic_registration: Optional[bool] = None
+
+
+@dataclass(repr=False)
+class DiagnosticClientCapabilities(Model):
+    dynamic_registration: Optional[bool] = None
+    related_document_support: Optional[bool] = None
+
+
 @dataclass(repr=False)
 class TextDocumentClientCapabilities(Model):
     synchronization: Optional[TextDocumentSyncClientCapabilities] = None
@@ -572,6 +638,10 @@ class TextDocumentClientCapabilities(Model):
     call_hierarchy: Optional[CallHierarchyClientCapabilities] = None
     semantic_tokens: Optional[SemanticTokensClientCapabilities] = None
     moniker: Optional[MonikerClientCapabilities] = None
+    # TODO typeHierarchy?: TypeHierarchyClientCapabilities;
+    inline_value: Optional[InlineValueClientCapabilities] = None
+    inlay_hint: Optional[InlayHintClientCapabilities] = None
+    diagnostic: Optional[DiagnosticClientCapabilities] = None
 
 
 @dataclass(repr=False)
@@ -599,6 +669,7 @@ class RegularExpressionsClientCapabilities(Model):
 class MarkdownClientCapabilities(Model):
     parser: str
     version: Optional[str] = None
+    allowed_tags: Optional[List[str]] = None
 
 
 @dataclass(repr=False)
@@ -612,6 +683,21 @@ class ClientCapabilitiesWorkspaceFileOperationsWorkspaceClientCapabilities(Model
     will_delete: Optional[bool] = None
 
 
+@dataclass(repr=False)
+class InlineValueWorkspaceClientCapabilities(Model):
+    refresh_support: Optional[bool] = None
+
+
+@dataclass(repr=False)
+class InlayHintWorkspaceClientCapabilities(Model):
+    refresh_support: Optional[bool] = None
+
+
+@dataclass(repr=False)
+class DiagnosticWorkspaceClientCapabilities(Model):
+    refresh_support: Optional[bool] = None
+
+
 @dataclass(repr=False)
 class ClientCapabilitiesWorkspace(Model):
     apply_edit: Optional[bool] = None
@@ -625,6 +711,9 @@ class ClientCapabilitiesWorkspace(Model):
     semantic_tokens: Optional[SemanticTokensWorkspaceClientCapabilities] = None
     code_lens: Optional[CodeLensWorkspaceClientCapabilities] = None
     file_operations: Optional[ClientCapabilitiesWorkspaceFileOperationsWorkspaceClientCapabilities] = None
+    inline_value: Optional[InlineValueWorkspaceClientCapabilities] = None
+    inlay_hint: Optional[InlayHintWorkspaceClientCapabilities] = None
+    diagnostics: Optional[DiagnosticWorkspaceClientCapabilities] = None
 
 
 @dataclass(repr=False)
@@ -634,10 +723,18 @@ class ClientCapabilitiesWindow(Model):
     show_document: Optional[ShowDocumentClientCapabilities] = None
 
 
+PositionEncodingKind = str
+
+UTF8: PositionEncodingKind = "utf-8"
+UTF16: PositionEncodingKind = "utf-16"
+UTF32: PositionEncodingKind = "utf-32"
+
+
 @dataclass(repr=False)
 class ClientCapabilitiesGeneral(Model):
     regular_expressions: Optional[RegularExpressionsClientCapabilities] = None
     markdown: Optional[MarkdownClientCapabilities] = None
+    position_encodings: Optional[List[PositionEncodingKind]] = None
 
 
 @dataclass(repr=False)
@@ -975,8 +1072,19 @@ class RenameRegistrationOptions(TextDocumentRegistrationOptions, RenameOptions,
     pass
 
 
+@dataclass(repr=False)
+class InlineValueOptions(WorkDoneProgressOptions):
+    pass
+
+
+@dataclass(repr=False)
+class InlineValueRegistrationOptions(InlineValueOptions, TextDocumentRegistrationOptions, StaticRegistrationOptions):
+    pass
+
+
 @dataclass(repr=False)
 class ServerCapabilities(Model):
+    position_encoding: Optional[PositionEncodingKind] = None
     text_document_sync: Union[TextDocumentSyncOptions, TextDocumentSyncKind, None] = None
     completion_provider: Optional[CompletionOptions] = None
     hover_provider: Union[bool, HoverOptions, None] = None
@@ -1004,6 +1112,9 @@ class ServerCapabilities(Model):
     # TODO call_hierarchy_provider: Union[boolean, CallHierarchyOptions, CallHierarchyRegistrationOptions, None] = None
     semantic_tokens_provider: Union[SemanticTokensOptions, SemanticTokensRegistrationOptions, None] = None
     # TODO moniker_provider: Union[bool, MonikerOptions, MonikerRegistrationOptions, None] = None
+
+    # TODO typeHierarchyProvider?: boolean | TypeHierarchyOptions | TypeHierarchyRegistrationOptions;
+    inline_value_provider: Union[bool, InlineValueOptions, InlineValueRegistrationOptions, None] = None
     workspace_symbol_provider: Union[bool, WorkspaceSymbolOptions, None] = None
     workspace: Optional[ServerCapabilitiesWorkspace] = None
     experimental: Optional[Any] = None
@@ -1336,15 +1447,6 @@ class FoldingRangeParams(WorkDoneProgressParams, _FoldingRangeParams):
     pass
 
 
-class FoldingRangeKind(Enum):
-    Comment = "comment"
-    Imports = "imports"
-    Region = "region"
-
-    def __repr__(self) -> str:  # pragma: no cover
-        return super().__str__()
-
-
 @dataclass(repr=False)
 class FoldingRange(Model):
     start_line: int
@@ -1352,6 +1454,7 @@ class FoldingRange(Model):
     start_character: Optional[int] = None
     end_character: Optional[int] = None
     kind: Union[FoldingRangeKind, str, None] = None
+    collapsed_text: Optional[str] = None
 
 
 @dataclass(repr=False)
@@ -2017,3 +2120,43 @@ class PrepareRenameResultWithDefaultBehavior(Model):
 
 
 PrepareRenameResult = Union[Range, PrepareRenameResultWithPlaceHolder, PrepareRenameResultWithDefaultBehavior]
+
+
+@dataclass(repr=False)
+class InlineValueContext(Model):
+    frame_id: int
+    stopped_location: Range
+
+
+@dataclass(repr=False)
+class _InlineValueParams(Model):
+    text_document: TextDocumentIdentifier
+    range: Range
+    context: InlineValueContext
+
+
+@dataclass(repr=False)
+class InlineValueParams(WorkDoneProgressParams, _InlineValueParams):
+    pass
+
+
+@dataclass(repr=False)
+class InlineValueText(Model):
+    range: Range
+    text: str
+
+
+@dataclass(repr=False)
+class InlineValueVariableLookup(Model):
+    range: Range
+    variable_name: Optional[str]
+    case_sensitive_lookup: bool
+
+
+@dataclass(repr=False)
+class InlineValueEvaluatableExpression(Model):
+    range: Range
+    expression: Optional[str]
+
+
+InlineValue = Union[InlineValueText, InlineValueVariableLookup, InlineValueEvaluatableExpression]
